@@ -1,5 +1,5 @@
 package Selenium::UserAgent;
-$Selenium::UserAgent::VERSION = '0.10';
+$Selenium::UserAgent::VERSION = '0.11';
 # ABSTRACT: Emulate mobile devices by setting user agents when using webdriver
 use Moo;
 use JSON;
@@ -120,12 +120,7 @@ has _chrome_options => (
                     'user-agent=' . $self->_get_user_agent,
                 ],
                 mobileEmulation => {
-                    deviceMetrics => {
-                        width => $size->{width} + 0,
-                        height => $size->{height} + 0,
-                        pixelRatio => $size->{pixel_ratio}
-                    },
-                    userAgent => $self->_get_user_agent
+                    deviceName => $self->_agent_to_chrome
                 }
             }
         }
@@ -157,7 +152,7 @@ sub caps {
     my $options = $self->_desired_options(%args);
 
     return {
-        inner_window_size => $self->_get_size_for('caps'),
+        # inner_window_size => $self->_get_size_for('caps'),
         desired_capabilities => {
             browserName => $self->browserName,
             %$options
@@ -225,6 +220,31 @@ sub _is_chrome {
     return shift->browserName =~ /chrome/i
 }
 
+sub _agent_to_chrome {
+    my ($self) = @_;
+
+    my $map = {
+        iphone4 => 'iPhone 4',
+        iphone5 => 'iPhone 5',
+        iphone6 => 'iPhone 6',
+        iphone6plus => 'iPhone 6 Plus',
+        ipad_mini => 'iPad Mini',
+        ipad => 'iPad',
+        galaxy_s3 => 'Galaxy S III',
+        galaxy_s5 => 'Galaxy S5',
+        galaxy_note3 => 'Galaxy Note 3',
+        nexus4 => 'Nexus 4',
+        nexus9 => 'Nexus 10',
+        nexus10 => 'Nexus 10',
+        iphone         => 'iPhone 4',
+        ipad_seven     => 'iPad',
+        android_phone  => 'Nexus 4',
+        android_tablet => 'Nexus 10'
+    };
+
+    return $map->{$self->agent};
+}
+
 1;
 
 __END__
@@ -241,7 +261,7 @@ Selenium::UserAgent - Emulate mobile devices by setting user agents when using w
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
